@@ -143,10 +143,56 @@ authorization from SunSoft Inc.
  *
  */
 
-#ifdef __unix__
+
+#ifdef PACKAGE_NAME
+/*
+  June 9, 2003, Adapted for use with configure by Bob Friesenhahn
+  Added the stupid check for autoconf by Marti Maria 
+*/
+typedef int	icSignature;
+
+typedef unsigned char	icUInt8Number;
+typedef unsigned short	icUInt16Number;
+typedef unsigned int	icUInt32Number;
+typedef unsigned int	icUInt64Number[2];
+
+typedef char	icInt8Number;
+typedef short	icInt16Number;
+typedef int	icInt32Number;
+typedef int	icInt64Number[2];
+
+typedef icInt32Number	icS15Fixed16Number;
+typedef icUInt32Number	icU16Fixed16Number;
+#else
+
+/* 
+ *Apr-17-2002: Modified by Marti Maria in order to provide wider portability.
+ */
+
+#if defined (__digital__) && defined (__unix__)
+
+/* Tru64 */
+
+#include <inttypes.h>
+
+typedef int32_t       icSignature; 
+
+typedef uint8_t   icUInt8Number;
+typedef uint16_t  icUInt16Number;
+typedef uint32_t  icUInt32Number;
+typedef uint32_t  icUInt64Number[2];
+
+typedef int8_t     icInt8Number;
+typedef int16_t    icInt16Number;
+typedef int32_t    icInt32Number;
+typedef int32_t    icInt64Number[2];
+
+typedef icInt32Number    icS15Fixed16Number;
+typedef icUInt32Number   icU16Fixed16Number;
+
+#else
 #ifdef __sgi
 #include "sgidefs.h"
-#endif
 
 typedef __int32_t       icSignature; 
 
@@ -175,27 +221,35 @@ typedef __uint32_t      icU16Fixed16Number;
 
 #include <sys/types.h>
 
-/* Sept-6-2001: added these type definitions. Modified by Marti Maria
- * in order to provide wider portability.
- */
-
 typedef int32_t       icSignature; 
 
+#ifdef __sun
+
+typedef uint8_t   icUInt8Number;
+typedef uint16_t  icUInt16Number;
+typedef uint32_t  icUInt32Number;
+typedef uint32_t  icUInt64Number[2];
+
+#else
+
 /* Unsigned integer numbers */
 typedef u_int8_t   icUInt8Number;
 typedef u_int16_t  icUInt16Number;
 typedef u_int32_t  icUInt32Number;
 typedef u_int32_t  icUInt64Number[2];
 
+#endif
+
+
 /* Signed numbers */
-typedef int8_t	   icInt8Number;
+typedef int8_t     icInt8Number;
 typedef int16_t    icInt16Number;
 typedef int32_t    icInt32Number;
 typedef int32_t    icInt64Number[2];
 
 /* Fixed numbers */
-typedef int32_t    icS15Fixed16Number;
-typedef u_int32_t   icU16Fixed16Number;
+typedef icInt32Number    icS15Fixed16Number;
+typedef icUInt32Number   icU16Fixed16Number;
 
 #else /* default definitions */
 
@@ -222,6 +276,8 @@ typedef long            icS15Fixed16Number;
 typedef unsigned long   icU16Fixed16Number;
 #endif  /* default defs */
 #endif
+#endif
+#endif
 
 /*------------------------------------------------------------------------*/
 /* public tags and sizes */
